Module engine

Module engine 

Provides a generic ExecutionEngine for all environments.

The execution engines primary responsibility is to orchestrate interactions between the ExecutionClient instances, and the rest of the platform. This includes sending commands to, and receiving events from, the trading venue endpoints via its registered execution clients.

Re-exports

pub use position::PositionStateSnapshot;
pub use position::SnapshotAnchorer;

Modules

config
position
Position types the ExecutionEngine publishes or carries between the stages of a fill correction.
stubs

Structs

ExecutionEngine
Central execution engine responsible for orchestrating order routing and execution.