pub struct MarketHoursFillModel { /* private fields */ }Expand description
Fill model that simulates varying conditions based on market hours. During low liquidity: wider spreads (one tick worse). Normal hours: standard liquidity.
Implementations
Sourceimpl MarketHoursFillModel
impl MarketHoursFillModel
Sourcepub fn new(
prob_fill_on_limit: f64,
prob_slippage: f64,
random_seed: Option<u64>,
) -> Result<Self>
pub fn new( prob_fill_on_limit: f64, prob_slippage: f64, random_seed: Option<u64>, ) -> Result<Self>
Creates a new MarketHoursFillModel instance.
Errors
Returns an error if probability parameters are not in range [0, 1].
pub fn set_low_liquidity_period(&mut self, is_low_liquidity: bool)
pub fn is_low_liquidity_period(&self) -> bool